@@ -68,10 +68,26 @@ class RESTInterface:
                 payload[key] = value
         return payload
 
+    def _handle_response_data(self, response):
+        try:
+            response_data = response.json()
+        except json.decoder.JSONDecodeError:
+            raise Exception(f"Error: {response.text}")
+        if response.ok:
+            return response_data
+        else:
+            raise Exception(response_data)
+
     def _get_resource(self, resource_path):
         r = requests.get(f"{self._api_url}/{resource_path}", headers=self._headers)
-        results = r.json()
-        return results
+        try:
+            response_data = r.json()
+        except json.decoder.JSONDecodeError:
+            raise Exception(f"Error: {r.text}")
+        if r.ok:
+            return response_data
+        else:
+            raise Exception(response_data)
 
     def _create_resource(self, resource_path, data):
         r = requests.post(
@@ -79,8 +95,7 @@ class RESTInterface:
             data=json.dumps(data),
             headers=self._headers,
         )
-        response_data = r.json()
-        return response_data
+        return self._handle_response_data(r)
 
     def _update_resource(self, resource_path, data):
         r = requests.patch(
@@ -88,10 +103,8 @@ class RESTInterface:
             data=json.dumps(data),
             headers=self._headers,
         )
-        response_data = r.json()
-        return response_data
+        return self._handle_response_data(r)
 
     def _delete_resource(self, resource_path):
         r = requests.delete(f"{self._api_url}/{resource_path}", headers=self._headers)
-        results = r.json()
-        return results
+        return self._handle_response_data(r)
