@@ -413,3 +413,37 @@ class Lister(RESTInterface):
         resource_path = f"users" + self._get_url_param_string(args, [])
         result = self._get_resource(resource_path)
         return result
+
+    # Plural methods
+    def api_keys(self, **kwargs):
+        return self.api_key(**kwargs)
+
+    def extractions(self, **kwargs):
+        return self.extraction(**kwargs)
+
+    def extraction_topics(self, **kwargs):
+        return self.extraction_topic(**kwargs)
+
+    def groups(self, **kwargs):
+        return self.group(**kwargs)
+
+    def group_associations(self, **kwargs):
+        return self.group_association(**kwargs)
+
+    def ingestions(self, **kwargs):
+        return self.ingestion(**kwargs)
+
+    def logs(self, **kwargs):
+        return self.log(**kwargs)
+
+    def message_types(self, **kwargs):
+        return self.message_type(**kwargs)
+
+    def records(self, **kwargs):
+        return self.record(**kwargs)
+
+    def topics(self, **kwargs):
+        return self.topic(**kwargs)
+
+    def users(self, **kwargs):
+        return self.user(**kwargs)
